function y = f_kepler(y,varargin)
% F_KEPLER Rght hand side for Kepler's 2 body problem.
%
%   Y = F_KEPLER(Y) computes the value of the right hand side for Kepler's
%   2 body problem.
%
%   Example:
%
%   y = f_kepler(y);

%   Copyright 2005-2005 Patrick Meury
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland
 
  q1 = y(1);
  q2 = y(2);
  p1 = y(3);
  p2 = y(4);
  
  nrm = sqrt(q1^2+q2^2);
  
  y(1) = p1;
  y(2) = p2;
  y(3) = -q1/nrm^3;
  y(4) = -q2/nrm^3;
  
return