function y = f_mp(y,varargin)
% F_MP Right hand side for the mathematical pendulum.
%
%   Y = F_MP(Y) computes the value of the right hand side for the
%   mathematical pendulum equation.
%
%   Example:
%
%   y = f_mp(y);

%   Copyright 2005-2005 Patrick Meury
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland
  
  % Extract input arguments

  q1 = y(1);
  q2 = y(2);
  p1 = y(3);
  p2 = y(4);
  
  lam = (p1^2+p2^2-q2)/(q1^2+q2^2);

  % Assign output arguments
  
  y(1) = p1;
  y(2) = p2;
  y(3) = -q1*lam;
  y(4) = -1-q2*lam; 
  
return