% Mathematical pendulum.

% Copyright 2005-2005 Patrick Meury
% SAM - Seminar for Applied Mathematics
% ETH-Zentrum
% CH-8092 Zurich, Switzerland

  h = 0.005;                  % Steps size
  nSteps = 10000;             % Time steps
  tol = 1e-8;                 % Error tolerance
  maxit = 20;                 % Maximum iterations
  y0 = [1; 1; 0; 0]/sqrt(2);  % Initial value
  f_handle = @f_mp;           % Right hand side
  g_handle = @g_mp;           % Constraints
  
  % Compute pendulum length
  
  g = sqrt(g_handle(y0,0,0));
  R = g(1);
  
  % Run Euler schemes
  
  y = impl_mdpt(y0,h,nSteps,tol,maxit,f_handle);
  
  % Compute values of constraints
  
  g = g_handle(y,R,0);
  
  % Generate figures
  
  figure('Name','Pendulum equation');
  plot(y(1,:),y(2,:),'r-');
  legend('impl. midpoint','Location','SouthEast');
  title('{\bf Pendulum equation}');
  xlabel('{\bf q_1}');
  ylabel('{\bf q_2}');
  set(gca,'XLim',[-1.5 1.5],'YLim',[-1.5 1.5],'DataAspectRatio',[1 1 1]);
  
  figure('Name','Constraints');
  plot(0:1:nSteps,sqrt(sum(g.^2,1)),'r.','MarkerSize',5);
  title('{\bf l^2-norm of constraints}');
  xlabel('{\bf Step number}');
  ylabel('{\bf Constraints [log]}');
  legend('impl. midpoint','Location','SouthEast');
  set(gca,'YScale','log');
 
  % Clear memory
  
  clear all;
  