function y = expl_Eul(y0,h,nSteps,f_handle,varargin)
% EXPL_EUL Explicit Euler scheme.
%
%   Y = EXPL_EUL(Y0,H,NSTEPS,F_HANDLE) computes the solution to the auto-
%   nomous ordinary differential equation
%
%     d/dt y = f(y) in (0,T),
%       y(0) = y0
%
%   using the NSTEPS time steps with step size H and initial data Y0.
%
%   Example:
%
%   y = expl_Eul(y0,h,nSteps,@f_mp);

%   Copyright 2005-2005 Patrick Meury
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland

  % Initialize constants
  
  dim = size(y0,1);  % Number of ODEs 
  
  % Preallocate memory
  
  y = zeros(dim,nSteps+1);

  % Copy initial value
  
  y(:,1) = y0;
  
  % Start explicit Euler scheme
  
  for i = 1:nSteps
    y(:,i+1) = y(:,i) + h*f_handle(y(:,i),varargin{:});  
  end
  
return